%define major	%{version}
%define libname	%mklibname %{name}_ %{major}
%define devname	%mklibname %{name} -d

Name:		radare2
Version:	5.8.8
%define subrel	2
Release:	%mkrel 1
Summary:	Reverse engineering framework and commandline tools security
License:	GPLv3+ and LGPLv3+
Group:		System/Libraries
Url:		https://www.radare.org/
Source0:	https://github.com/radareorg/radare2/releases/download/%{version}/%{name}-%{version}.tar.xz
# CVE-2023-4322 - radare2: Heap-based Buffer Overflow in the bf dissassembler
# fix should be part of 5.9.0
# https://github.com/radareorg/radare2/commit/ba919adb74ac368bf76b150a00347ded78b572dd
Patch5:		radare2-5.8.8-CVE-2023-4322.patch
# CVE-2023-5686 - radare2: heap-buffer-overflow in /radare2/shlr/java/code.c:211:21 in java_print_opcode
# fix should be part of 5.9.0
# https://github.com/radareorg/radare2/commit/1bdda93e348c160c84e30da3637acef26d0348de
Patch6:		radare2-5.8.8-CVE-2023-5686.patch
# https://github.com/radareorg/radare2/commit/40c9f50e127be80b9d816bce2ab2ee790831aefd
Patch7:		radare2-5.8.8-CVE-2023-47016.patch

BuildRequires:	meson
BuildRequires:	gmp-devel
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(capstone)
BuildRequires:	pkgconfig(libuv)
BuildRequires:	pkgconfig(liblz4)
BuildRequires:	pkgconfig(libmagic)
BuildRequires:	pkgconfig(libxxhash)
BuildRequires:	pkgconfig(libzip)
BuildRequires:	pkgconfig(openssl) >= 1.1
BuildRequires:	pkgconfig(zlib)

%description
Radare2 is a rewrite from scratch of radare in order to provide a set
of libraries and tools to work with binary files.

Radare project started as a forensics tool, a scriptable commandline
hexadecimal editor able to open disk files, but later support for
analyzing binaries, disassembling code, debugging programs, attaching
to remote gdb servers, ...

#------------------------------------------------

%package -n	%{libname}
Summary:	Reverse engineering framework and commandline tools security
Group:		System/Libraries

%description -n	%{libname}
Radare2 is a rewrite from scratch of radare in order to provide a set
of libraries and tools to work with binary files.

Radare project started as a forensics tool, a scriptable commandline
hexadecimal editor able to open disk files, but later support for
analyzing binaries, disassembling code, debugging programs, attaching
to remote gdb servers, ...

#------------------------------------------------

%package -n	%{devname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{devname}
Header files for development with %{name}.

#------------------------------------------------


%prep
%autosetup -p1

%build
# Whereever possible use the system-wide libraries instead of bundles
%meson \
    -Duse_sys_magic=true \
    -Duse_sys_zip=true \
    -Duse_sys_zlib=true \
    -Duse_sys_lz4=true \
    -Duse_sys_xxhash=true \
    -Duse_sys_openssl=true \
    -Duse_libuv=true \
    -Duse_sys_capstone=true
%meson_build

%install
%meson_install

%files
%doc CONTRIBUTING.md DEVELOPERS.md
%doc %{_docdir}/%{name}/
%license COPYING
%{_bindir}/r2
%{_bindir}/r2agent
%{_bindir}/r2pm
%{_bindir}/r2r
%{_bindir}/rabin2
%{_bindir}/radare2
%{_bindir}/radiff2
%{_bindir}/rafind2
%{_bindir}/ragg2
%{_bindir}/rahash2
%{_bindir}/rarun2
%{_bindir}/rasign2
%{_bindir}/rasm2
%{_bindir}/ravc2
%{_bindir}/rax2
%{_datadir}/%{name}/
%{_datadir}/zsh/site-functions/_r*
%{_mandir}/man1/r*.1.*
%{_mandir}/man7/esil.7.*

%files -n %{libname}
%license COPYING
%{_libdir}/libr*.so.%{major}

%files -n %{devname}
%license COPYING
%{_includedir}/libr/
%{_libdir}/libr*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Wed Sep 11 2024 daviddavid <daviddavid> 5.8.8-1.2.mga9
+ Revision: 2095054
- backport upstream patch to fix CVE-2023-47016 (mga#33534)
- cherrypick from upstream master patches for known vulnerabilities (mga#32521):
  * CVE-2023-4322 - heap-buffer-overflow in the brainfuck dissassembler
  * CVE-2023-5686 - heap-buffer-overflow in /radare2/shlr/java/code.c

* Mon Jul 03 2023 daviddavid <daviddavid> 5.8.8-1.mga9
+ Revision: 1963528
- new version: 5.8.8
- use system xxhash and libmagic

* Sun Feb 26 2023 daviddavid <daviddavid> 5.8.2-2.mga9
+ Revision: 1945529
- cherrypick upstream patch for fixing the sdb generation from meson

* Sat Feb 04 2023 daviddavid <daviddavid> 5.8.2-1.mga9
+ Revision: 1938046
- new version: 5.8.2
- fix CVE-2023-0302 and CVE-2023-0302

* Sun Jan 08 2023 daviddavid <daviddavid> 5.8.0-1.mga9
+ Revision: 1931605
- new version: 5.8.0

* Sun Jan 01 2023 daviddavid <daviddavid> 5.7.8-1.mga9
+ Revision: 1928674
- new version: 5.7.8

* Mon Aug 22 2022 papoteur <papoteur> 5.7.6-1.mga9
+ Revision: 1879260
- new version: 5.7.6
- fix CVE-2022-34502

* Fri Apr 01 2022 umeabot <umeabot> 5.5.4-2.mga9
+ Revision: 1838986
- Mageia 9 Mass Rebuild

* Sun Jan 02 2022 neoclust <neoclust> 5.5.4-1.mga9
+ Revision: 1766216
- New version 5.5.4: Fixes CVE-2021-32613 and CVE-2021-3673 (mga#29163)

* Sat Oct 02 2021 wally <wally> 5.1.1-2.mga9
+ Revision: 1747878
- rebuild for openssl 3.0.0

* Fri Mar 05 2021 neoclust <neoclust> 5.1.1-1.mga9
+ Revision: 1699629
- New version 5.1.1: Fixes CVE-2020-16269 and CVE-2020-17487 (mga#28476)

* Tue Dec 22 2020 daviddavid <daviddavid> 4.5.1-1.mga8
+ Revision: 1662775
- new version: 4.5.1

* Sun Aug 02 2020 daviddavid <daviddavid> 4.5.0-1.mga8
+ Revision: 1610493
- new version: 4.5.0

* Sat May 23 2020 daviddavid <daviddavid> 4.4.0-1.mga8
+ Revision: 1586922
- new version: 4.4.0

* Tue Mar 31 2020 daviddavid <daviddavid> 4.3.1-1.mga8
+ Revision: 1562519
- new version: 4.3.1

* Thu Feb 20 2020 daviddavid <daviddavid> 4.2.1-1.mga8
+ Revision: 1547577
- new version: 4.2.1, fixes CVE-2019-19590 and CVE-2019-19647 (mga#26232)

* Tue Feb 18 2020 umeabot <umeabot> 4.1.1-2.mga8
+ Revision: 1541496
- Mageia 8 Mass Rebuild

* Sat Dec 28 2019 daviddavid <daviddavid> 4.1.1-1.mga8
+ Revision: 1474582
- new version: 4.1.1 (reantull)

* Wed Oct 02 2019 daviddavid <daviddavid> 3.8.0-1.mga8
+ Revision: 1448857
- new version: 3.8.0

* Wed Jul 17 2019 daviddavid <daviddavid> 3.6.0-1.mga8
+ Revision: 1422006
- new version: 3.6.0

* Thu Apr 18 2019 daviddavid <daviddavid> 3.4.1-1.mga7
+ Revision: 1393120
- new version: 3.4.1

* Thu Apr 18 2019 umeabot <umeabot> 3.3.0-2.mga7
+ Revision: 1392913
- Rebuild with meson 0.50.1

* Mon Feb 25 2019 daviddavid <daviddavid> 3.3.0-1.mga7
+ Revision: 1370017
- new version: 3.3.0

* Tue Jan 22 2019 daviddavid <daviddavid> 3.2.1-1.mga7
+ Revision: 1359451
- new version: 3.2.1

* Mon Jan 14 2019 daviddavid <daviddavid> 3.2.0-3.mga7
+ Revision: 1356392
- use bundled radare2 magic libraries until an upstream radare2-cutter fix
  * https://github.com/radareorg/cutter/issues/1108

* Sun Jan 13 2019 daviddavid <daviddavid> 3.2.0-2.mga7
+ Revision: 1355887
- new version: 3.2.0
- switch to meson build system

* Sat Jan 12 2019 tv <tv> 2.9.0-2.mga7
+ Revision: 1355779
- rebuild for new capstone

* Thu Sep 06 2018 daviddavid <daviddavid> 2.9.0-1.mga7
+ Revision: 1257555
- new version: 2.9.0

* Tue Aug 14 2018 daviddavid <daviddavid> 2.8.0-1.mga7
+ Revision: 1251442
- new version: 2.8.0

* Wed Jul 11 2018 daviddavid <daviddavid> 2.7.0-1.mga7
+ Revision: 1243092
- new version: 2.7.0

* Thu Jul 05 2018 daviddavid <daviddavid> 2.6.9-1.mga7
+ Revision: 1241725
- new version: 2.6.9

* Sun May 20 2018 daviddavid <daviddavid> 2.5.0-1.mga7
+ Revision: 1230585
- initial package radare2

